@@ -447,7 +447,7 @@ keys = {
 }
 
 
-def wait_for_input(time_max=None):
+def wait_for_input(time_max=None, unicode = False):
     
     """
     Low level input checker.
@@ -534,17 +534,22 @@ def wait_for_input(time_max=None):
     else:
         while event_tc[-1].type != pygame.KEYDOWN:
             event_tc.pop()
-        try:
-
-            print(event_tc[-1])
-            return(keys[modifier][event_tc[-1].key])
+            
+        if unicode:
+            return(event_tc[-1].unicode)
         
-        except (KeyError, AttributeError):
-            return(event.key)
+        else:
+            try:
+    
+                print(event_tc[-1])
+                return(keys[modifier][event_tc[-1].key])
+            
+            except (KeyError, AttributeError):
+                return(event.key)
 
 
 def response(allow=None, enable_escape=True, 
-             time_max=None, get_RT=True):
+             time_max=None, get_RT=True, unicode = False):
     
     """
     Get a (keyboard, for now) response.
@@ -582,7 +587,10 @@ def response(allow=None, enable_escape=True,
             allow = [allow]
 
     while True:
-        pressed_key = wait_for_input(time_max=time_max)
+        if unicode:
+            pressed_key = wait_for_input(time_max=time_max, unicode = True)
+        else:
+            pressed_key = wait_for_input(time_max=time_max)
         if pressed_key == "Time_Max_Exceeded":
             return("Time_Max_Exceeded", local_time.get())
         
@@ -697,7 +705,9 @@ class Coordinates:
             return(int(distance_x), int(distance_y))
 
 
-    def from_pygame(x=None, y=None):
+
+    def from_pygame(x=None, y=None,
+                    distance_x=None, distance_y=None):
         
         """
         Help incomplete, sorry.
@@ -736,6 +746,20 @@ class Coordinates:
             y = -(20*y/screen_height) + 10
             return(x, y)
 
+        if distance_x != None and distance_y is None:
+            distance_x = (distance_x)*(10.0+10.0)/(screen_width-0.0)
+            return(distance_x)
+
+        if distance_y != None and distance_x is None:
+            distance_y = (distance_y)*(10.0+10.0)/(screen_height-0.0)
+            return(distance_y)
+        
+        if distance_x != None and distance_y != None:
+            distance_x = (distance_x)*(10.0+10.0)/(screen_width-0.0)
+            distance_y = (distance_y)*(10.0+10.0)/(screen_height-0.0)
+            return(distance_x, distance_y)
+
+        
 
     def to_physical(distance_x=None, distance_y=None, 
                     monitor_diagnonal=monitor_diagonal, unit="cm"):
